==> integration-tests-jobs-service-springboot-1.40.1-20230625.030328-1-sources.jar: org/acme/processes/MultipleTimerInstancesBoundaryTimerEventProcess.java <==
package org.acme.processes;

import org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel;
import org.kie.api.definition.process.Process;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.drools.core.util.KieFunctions;

@org.springframework.stereotype.Component("MultipleTimerInstancesBoundaryTimerEvent")
public class MultipleTimerInstancesBoundaryTimerEventProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel> {

    @org.springframework.beans.factory.annotation.Autowired()
    public MultipleTimerInstancesBoundaryTimerEventProcess(org.kie.kogito.app.Application app, org.kie.kogito.correlation.CorrelationService correlations) {
        super(app, java.util.Arrays.asList(), correlations);
        activate();
    }

    public MultipleTimerInstancesBoundaryTimerEventProcess() {
    }

    @Override()
    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel value) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, value, this.createProcessRuntime());
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(java.lang.String businessKey, org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel value) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, value, businessKey, this.createProcessRuntime());
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.correlation.CompositeCorrelation correlation, org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel value) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, value, businessKey, this.createProcessRuntime(), correlation);
    }

    @Override()
    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel createModel() {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel();
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel) value);
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel) value);
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, this.createModel(), this.createProcessRuntime(), wpi);
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createReadOnlyInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, this.createModel(), wpi);
    }

    protected org.kie.api.definition.process.Process process() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("MultipleTimerInstancesBoundaryTimerEvent", true);
        factory.name("MultipleTimerInstancesBoundaryTimerEvent");
        factory.packageName("org.acme.processes");
        factory.dynamic(false);
        factory.version("1.0");
        factory.type("BPMN");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode1 = factory.endNode(1);
        endNode1.name("End");
        endNode1.terminate(false);
        endNode1.metaData("UniqueId", "_64A50D8D-8741-4F77-9A97-38F28FD6D447");
        endNode1.metaData("x", 773);
        endNode1.metaData("width", 56);
        endNode1.metaData("y", 387);
        endNode1.metaData("height", 56);
        endNode1.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode2 = factory.actionNode(2);
        actionNode2.name("Script2");
        actionNode2.action(kcontext -> {
            System.out.println("MultipleTimerInstancesBoundaryTimerEvent.Script2: " + java.time.ZonedDateTime.now());
        });
        actionNode2.metaData("UniqueId", "_047C4181-1503-4A6B-A3B4-ECA82E6524AA");
        actionNode2.metaData("elementname", "Script2");
        actionNode2.metaData("NodeType", "ScriptTask");
        actionNode2.metaData("x", 539);
        actionNode2.metaData("width", 154);
        actionNode2.metaData("y", 364);
        actionNode2.metaData("height", 102);
        actionNode2.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode3 = factory.endNode(3);
        endNode3.name("End");
        endNode3.terminate(false);
        endNode3.metaData("UniqueId", "_22F3979A-AEA9-4B67-8221-4E9A225DFD85");
        endNode3.metaData("x", 770);
        endNode3.metaData("width", 56);
        endNode3.metaData("y", 144);
        endNode3.metaData("height", 56);
        endNode3.done();
        org.jbpm.ruleflow.core.factory.HumanTaskNodeFactory<?> humanTaskNode4 = factory.humanTaskNode(4);
        humanTaskNode4.name("Task1");
        humanTaskNode4.workParameter("NodeName", "Task1");
        humanTaskNode4.workParameter("TaskName", "Task1");
        humanTaskNode4.workParameter("GroupId", "HR");
        humanTaskNode4.workParameter("Skippable", "false");
        humanTaskNode4.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_TaskNameInputX", "TaskName", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("9a54a818-7cbd-4ecf-976a-3e1fd059b893", "EXPRESSION (Task1)", "java.lang.Object", "Task1"), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_TaskNameInputX", "TaskName", "Object", null))), null));
        humanTaskNode4.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_SkippableInputX", "Skippable", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("0919f831-b813-4483-903f-664aa0a38c1b", "EXPRESSION (false)", "java.lang.Object", "false"), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_SkippableInputX", "Skippable", "Object", null))), null));
        humanTaskNode4.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_GroupIdInputX", "GroupId", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("1b9af460-6cef-4fad-b29c-95f43bb27995", "EXPRESSION (HR)", "java.lang.Object", "HR"), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_GroupIdInputX", "GroupId", "Object", null))), null));
        humanTaskNode4.done();
        humanTaskNode4.metaData("UniqueId", "_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6");
        humanTaskNode4.metaData("elementname", "Task1");
        humanTaskNode4.metaData("x", 536);
        humanTaskNode4.metaData("width", 154);
        humanTaskNode4.metaData("y", 121);
        humanTaskNode4.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode5 = factory.actionNode(5);
        actionNode5.name("Script1");
        actionNode5.action(kcontext -> {
            System.out.println("MultipleTimerInstancesBoundaryTimerEvent.Script1: " + java.time.ZonedDateTime.now());
        });
        actionNode5.metaData("UniqueId", "_E29BD688-B537-4324-B8B9-5944A0FCF9EF");
        actionNode5.metaData("elementname", "Script1");
        actionNode5.metaData("NodeType", "ScriptTask");
        actionNode5.metaData("x", 302);
        actionNode5.metaData("width", 154);
        actionNode5.metaData("y", 121);
        actionNode5.metaData("height", 102);
        actionNode5.done();
        org.jbpm.ruleflow.core.factory.StartNodeFactory<?> startNode6 = factory.startNode(6);
        startNode6.name("Start");
        startNode6.interrupting(true);
        startNode6.metaData("UniqueId", "_A2723166-5057-4199-B4A5-61C25D0A50A9");
        startNode6.metaData("x", 166);
        startNode6.metaData("width", 56);
        startNode6.metaData("y", 144);
        startNode6.metaData("height", 56);
        startNode6.done();
        org.jbpm.ruleflow.core.factory.BoundaryEventNodeFactory<?> boundaryEventNode7 = factory.boundaryEventNode(7);
        boundaryEventNode7.name("BoundaryEvent");
        boundaryEventNode7.eventType("Timer-_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6-PT10S-7");
        boundaryEventNode7.attachedTo("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6");
        boundaryEventNode7.scope(null);
        boundaryEventNode7.metaData("UniqueId", "_415F8A44-E59D-48B1-8998-2B3DB85C9E53");
        boundaryEventNode7.metaData("EventType", "timer");
        boundaryEventNode7.metaData("x", 588);
        boundaryEventNode7.metaData("width", 56);
        boundaryEventNode7.metaData("y", 195);
        boundaryEventNode7.metaData("AttachedTo", "_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6");
        boundaryEventNode7.metaData("TimeDuration", "PT10S");
        boundaryEventNode7.metaData("CancelActivity", true);
        boundaryEventNode7.metaData("height", 56);
        boundaryEventNode7.done();
        factory.connection(2, 1, "_638ECD05-BFB2-4CDF-B517-FBBDAA364B9E");
        factory.connection(7, 2, "_8F723F32-429A-4133-AD88-E64BB0AB10DA");
        factory.connection(4, 3, "_DE5805E3-F291-4D85-8824-94F9D1F0C42B");
        factory.connection(5, 4, "_167ECDC4-16E2-434B-A2D8-40926EE4E8C7");
        factory.connection(6, 5, "_F1255546-39EF-4F6C-BB2E-452B342F3D1B");
        factory.validate();
        return factory.getProcess();
    }
}

==> integration-tests-jobs-service-springboot-3.0.0-20231201.044652-1-sources.jar: org/acme/processes/MultipleTimerInstancesBoundaryTimerEventProcess.java <==
package org.acme.processes;

import org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel;
import org.kie.api.definition.process.Process;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.drools.core.util.KieFunctions;

@org.springframework.stereotype.Component("MultipleTimerInstancesBoundaryTimerEvent")
public class MultipleTimerInstancesBoundaryTimerEventProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel> {

    @org.springframework.beans.factory.annotation.Autowired()
    public MultipleTimerInstancesBoundaryTimerEventProcess(org.kie.kogito.app.Application app, org.kie.kogito.correlation.CorrelationService correlations) {
        super(app, java.util.Arrays.asList(), correlations);
        activate();
    }

    public MultipleTimerInstancesBoundaryTimerEventProcess() {
    }

    @Override()
    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel value) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, value, this.createProcessRuntime());
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(java.lang.String businessKey, org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel value) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, value, businessKey, this.createProcessRuntime());
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.correlation.CompositeCorrelation correlation, org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel value) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, value, businessKey, this.createProcessRuntime(), correlation);
    }

    @Override()
    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel createModel() {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel();
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel) value);
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.processes.MultipleTimerInstancesBoundaryTimerEventModel) value);
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, this.createModel(), this.createProcessRuntime(), wpi);
    }

    public org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance createReadOnlyInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.processes.MultipleTimerInstancesBoundaryTimerEventProcessInstance(this, this.createModel(), wpi);
    }

    protected org.kie.api.definition.process.Process process() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("MultipleTimerInstancesBoundaryTimerEvent", true);
        factory.name("MultipleTimerInstancesBoundaryTimerEvent");
        factory.packageName("org.acme.processes");
        factory.dynamic(false);
        factory.version("1.0");
        factory.type("BPMN");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode1 = factory.endNode(1);
        endNode1.name("End");
        endNode1.terminate(false);
        endNode1.metaData("UniqueId", "_64A50D8D-8741-4F77-9A97-38F28FD6D447");
        endNode1.metaData("x", 773);
        endNode1.metaData("width", 56);
        endNode1.metaData("y", 387);
        endNode1.metaData("height", 56);
        endNode1.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode2 = factory.actionNode(2);
        actionNode2.name("Script2");
        actionNode2.action(kcontext -> {
            System.out.println("MultipleTimerInstancesBoundaryTimerEvent.Script2: " + java.time.ZonedDateTime.now());
        });
        actionNode2.metaData("UniqueId", "_047C4181-1503-4A6B-A3B4-ECA82E6524AA");
        actionNode2.metaData("elementname", "Script2");
        actionNode2.metaData("NodeType", "ScriptTask");
        actionNode2.metaData("x", 539);
        actionNode2.metaData("width", 154);
        actionNode2.metaData("y", 364);
        actionNode2.metaData("height", 102);
        actionNode2.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode3 = factory.endNode(3);
        endNode3.name("End");
        endNode3.terminate(false);
        endNode3.metaData("UniqueId", "_22F3979A-AEA9-4B67-8221-4E9A225DFD85");
        endNode3.metaData("x", 770);
        endNode3.metaData("width", 56);
        endNode3.metaData("y", 144);
        endNode3.metaData("height", 56);
        endNode3.done();
        org.jbpm.ruleflow.core.factory.HumanTaskNodeFactory<?> humanTaskNode4 = factory.humanTaskNode(4);
        humanTaskNode4.name("Task1");
        humanTaskNode4.workParameter("NodeName", "Task1");
        humanTaskNode4.workParameter("TaskName", "Task1");
        humanTaskNode4.workParameter("GroupId", "HR");
        humanTaskNode4.workParameter("Skippable", "false");
        humanTaskNode4.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_TaskNameInputX", "TaskName", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("ad2a4af8-badb-46c7-b5ce-3f356fbd5530", "EXPRESSION (Task1)", "java.lang.Object", "Task1"), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_TaskNameInputX", "TaskName", "Object", null))), null));
        humanTaskNode4.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_SkippableInputX", "Skippable", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("06c2005e-5999-48d2-8f6f-3ebae92acf90", "EXPRESSION (false)", "java.lang.Object", "false"), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_SkippableInputX", "Skippable", "Object", null))), null));
        humanTaskNode4.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_GroupIdInputX", "GroupId", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("03e944cf-b8d2-49bc-95bd-eeca2a9fb8d0", "EXPRESSION (HR)", "java.lang.Object", "HR"), new org.jbpm.workflow.core.impl.DataDefinition("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6_GroupIdInputX", "GroupId", "Object", null))), null));
        humanTaskNode4.done();
        humanTaskNode4.metaData("UniqueId", "_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6");
        humanTaskNode4.metaData("elementname", "Task1");
        humanTaskNode4.metaData("x", 536);
        humanTaskNode4.metaData("width", 154);
        humanTaskNode4.metaData("y", 121);
        humanTaskNode4.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode5 = factory.actionNode(5);
        actionNode5.name("Script1");
        actionNode5.action(kcontext -> {
            System.out.println("MultipleTimerInstancesBoundaryTimerEvent.Script1: " + java.time.ZonedDateTime.now());
        });
        actionNode5.metaData("UniqueId", "_E29BD688-B537-4324-B8B9-5944A0FCF9EF");
        actionNode5.metaData("elementname", "Script1");
        actionNode5.metaData("NodeType", "ScriptTask");
        actionNode5.metaData("x", 302);
        actionNode5.metaData("width", 154);
        actionNode5.metaData("y", 121);
        actionNode5.metaData("height", 102);
        actionNode5.done();
        org.jbpm.ruleflow.core.factory.StartNodeFactory<?> startNode6 = factory.startNode(6);
        startNode6.name("Start");
        startNode6.interrupting(true);
        startNode6.metaData("UniqueId", "_A2723166-5057-4199-B4A5-61C25D0A50A9");
        startNode6.metaData("x", 166);
        startNode6.metaData("width", 56);
        startNode6.metaData("y", 144);
        startNode6.metaData("height", 56);
        startNode6.done();
        org.jbpm.ruleflow.core.factory.BoundaryEventNodeFactory<?> boundaryEventNode7 = factory.boundaryEventNode(7);
        boundaryEventNode7.name("BoundaryEvent");
        boundaryEventNode7.eventType("Timer-_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6-PT10S-7");
        boundaryEventNode7.attachedTo("_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6");
        boundaryEventNode7.scope(null);
        boundaryEventNode7.metaData("UniqueId", "_415F8A44-E59D-48B1-8998-2B3DB85C9E53");
        boundaryEventNode7.metaData("EventType", "timer");
        boundaryEventNode7.metaData("x", 588);
        boundaryEventNode7.metaData("width", 56);
        boundaryEventNode7.metaData("y", 195);
        boundaryEventNode7.metaData("AttachedTo", "_D63BF8F7-0F6B-4889-9F96-04E1F710DEA6");
        boundaryEventNode7.metaData("TimeDuration", "PT10S");
        boundaryEventNode7.metaData("CancelActivity", true);
        boundaryEventNode7.metaData("height", 56);
        boundaryEventNode7.done();
        factory.connection(2, 1, "_638ECD05-BFB2-4CDF-B517-FBBDAA364B9E");
        factory.connection(7, 2, "_8F723F32-429A-4133-AD88-E64BB0AB10DA");
        factory.connection(4, 3, "_DE5805E3-F291-4D85-8824-94F9D1F0C42B");
        factory.connection(5, 4, "_167ECDC4-16E2-434B-A2D8-40926EE4E8C7");
        factory.connection(6, 5, "_F1255546-39EF-4F6C-BB2E-452B342F3D1B");
        factory.validate();
        return factory.getProcess();
    }
}
